summaryrefslogtreecommitdiff
path: root/alembic/ddl
diff options
context:
space:
mode:
authorMike Bayer <mike_mp@zzzcomputing.com>2012-01-24 16:33:34 -0500
committerMike Bayer <mike_mp@zzzcomputing.com>2012-01-24 16:33:34 -0500
commitdfcfc872319acbadbf95ee75f555be0fd7ca8e6f (patch)
treee574f2929c91f5733592a46a4996d896a324397c /alembic/ddl
parent14d05f4b062c1cd237447f66467e234ee30ab3f7 (diff)
downloadalembic-dfcfc872319acbadbf95ee75f555be0fd7ca8e6f.tar.gz
documentation updates for 0.2
Diffstat (limited to 'alembic/ddl')
-rw-r--r--alembic/ddl/impl.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/alembic/ddl/impl.py b/alembic/ddl/impl.py
index 74cc94b..08134b5 100644
--- a/alembic/ddl/impl.py
+++ b/alembic/ddl/impl.py
@@ -190,7 +190,7 @@ class DefaultImpl(object):
return conn_col_default != rendered_metadata_default
def start_migrations(self):
"""A hook called when :meth:`.Context.run_migrations`
is called.
Implementations can set up per-migration-run state here.
@@ -202,7 +202,7 @@ class DefaultImpl(object):
equivalent, on the current connection context.
This is used in offline mode and typically
- via :func:`.context.begin_transaction`.
+ via :meth:`.EnvironmentContext.begin_transaction`.
"""
self.static_output("BEGIN;")
@@ -212,7 +212,7 @@ class DefaultImpl(object):
equivalent, on the current connection context.
This is used in offline mode and typically
- via :func:`.context.begin_transaction`.
+ via :meth:`.EnvironmentContext.begin_transaction`.
"""
self.static_output("COMMIT;")
@@ -190,7 +190,7 @@ class DefaultImpl(object):
return conn_col_default != rendered_metadata_default
def start_migrations(self):
- """A hook called when :meth:`.Context.run_migrations`
+ """A hook called when :meth:`.EnvironmentContext.run_migrations`
is called.
Implementations can set up per-migration-run state here.